googleCloudProjectIdZoneVariable top-level constant
String
const googleCloudProjectIdZoneVariable
The unique ID String for the current project when run on Google Cloud.
This variable is looked up in the current Zone to correlate logs with the GCP project context. Framework middleware should set this in a forked zone.
Implementation
const googleCloudProjectIdZoneVariable =
'google_cloud_logging.google_cloud_project';