traceparentHeaderValueZoneVariable top-level constant
String
const traceparentHeaderValueZoneVariable
The String value for the traceparent W3C HTTP header.
This variable is looked up in the current Zone to associate log entries with the trace and span context of the incoming request.
Implementation
const traceparentHeaderValueZoneVariable = 'google_cloud_logging.traceparent';